==> org.eclipse.lsp4e.jdt.source_0.13.0.202402070603.jar: org/eclipse/lsp4e/jdt/LSJavaProposalExtension.java <==
/*******************************************************************************
 * Copyright (c) 2024 Broadcom Inc. and others.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *  - Alex Boyko (VMware Inc.) - Initial implementation
 *******************************************************************************/
package org.eclipse.lsp4e.jdt;

import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.contentassist.ICompletionProposal;
import org.eclipse.jface.text.contentassist.ICompletionProposalExtension;

class LSJavaProposalExtension extends LSJavaProposal implements ICompletionProposalExtension {

	public LSJavaProposalExtension(ICompletionProposal delegate, int relevance) {
		super(delegate, relevance);
	}

	@Override
	public void apply(IDocument doc, char trigger, int offset) {
		if (delegate instanceof ICompletionProposalExtension) {
			((ICompletionProposalExtension) delegate).apply(doc, trigger, offset);
		}
	}

	@Override
	public int getContextInformationPosition() {
		if (delegate instanceof ICompletionProposalExtension) {
			((ICompletionProposalExtension) delegate).getContextInformationPosition();
		}
		return -1;
	}

	@Override
	public char[] getTriggerCharacters() {
		if (delegate instanceof ICompletionProposalExtension) {
			((ICompletionProposalExtension) delegate).getTriggerCharacters();
		}
		return null;
	}

	@Override
	public boolean isValidFor(IDocument doc, int offset) {
		if (delegate instanceof ICompletionProposalExtension) {
			((ICompletionProposalExtension) delegate).isValidFor(doc, offset);
		}
		return false;
	}

}

==> org.eclipse.lsp4e.jdt.source_0.13.1.202409041348.jar: org/eclipse/lsp4e/jdt/LSJavaProposalExtension.java <==
/*******************************************************************************
 * Copyright (c) 2024 Broadcom Inc. and others.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *  - Alex Boyko (VMware Inc.) - Initial implementation
 *******************************************************************************/
package org.eclipse.lsp4e.jdt;

import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.contentassist.ICompletionProposal;
import org.eclipse.jface.text.contentassist.ICompletionProposalExtension;

class LSJavaProposalExtension extends LSJavaProposal implements ICompletionProposalExtension {

	public LSJavaProposalExtension(ICompletionProposal delegate, int relevance) {
		super(delegate, relevance);
	}

	@Override
	public void apply(IDocument doc, char trigger, int offset) {
		if (delegate instanceof ICompletionProposalExtension proposalExt) {
			proposalExt.apply(doc, trigger, offset);
		}
	}

	@Override
	public int getContextInformationPosition() {
		if (delegate instanceof ICompletionProposalExtension proposalExt) {
			proposalExt.getContextInformationPosition();
		}
		return -1;
	}

	@Override
	public char @Nullable [] getTriggerCharacters() {
		if (delegate instanceof ICompletionProposalExtension proposalExt) {
			proposalExt.getTriggerCharacters();
		}
		return null;
	}

	@Override
	public boolean isValidFor(IDocument doc, int offset) {
		if (delegate instanceof ICompletionProposalExtension proposalExt) {
			proposalExt.isValidFor(doc, offset);
		}
		return false;
	}

}
